@@ -33,15 +33,15 @@
    *\note if the j is -1 then all the card are shown
  */
 require_once '../include/constant.php';
-require_once NOALYSS_INCLUDE.'/class_own.php';
-require_once NOALYSS_INCLUDE.'/class_database.php';
-require_once NOALYSS_INCLUDE.'/user_common.php';
-require_once NOALYSS_INCLUDE.'/class_dossier.php';
+require_once NOALYSS_INCLUDE.'/class/class_own.php';
+require_once NOALYSS_INCLUDE.'/lib/class_database.php';
+require_once NOALYSS_INCLUDE.'/lib/user_common.php';
+require_once NOALYSS_INCLUDE.'/class/class_dossier.php';
 $gDossier=dossier::id();
 
-require_once('class_user.php');
+require_once('class/class_user.php');
 
-$cn=new Database(dossier::id());
+$cn=Dossier::connect();
 global $g_user;
 $g_user=new User($cn);
 $g_user->check();
