@@ -3,7 +3,7 @@
 //see licence.txt
 
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once NOALYSS_INCLUDE.'/class_anc_group.php';
+require_once NOALYSS_INCLUDE.'/class/class_anc_group.php';
 
 $gr = new Anc_Group($cn);
 $gr->get_request();
